@@ -10,7 +10,7 @@ from operator import itemgetter
 import psycopg2
 import psycopg2.extras
 
-__version__ = '0.3'
+__version__ = '0.4'
 __all__ = ['Event', 'Batch', 'Consumer', 'Queue', 'Ticker',
            'bulk_insert_events', 'insert_event']
 
@@ -147,6 +147,7 @@ class Batch(object):
         self.fetch_status = 0   # 0-not started, 1-in-progress, 2-done
 
     def _make_event(self, row):
+        row['ev_retry'] = row['ev_retry'] or 0
         return Event([row['ev_' + fld] for fld in Event._fields[:-1]] +
                      [self.failed])
 
@@ -457,7 +458,7 @@ class Consumer(object):
         return self.queue.unregister_consumer(curs, self.consumer_name)
 
     def get_info(self, curs):
-        """Get info abouti the queue."""
+        """Get info about the queue."""
         return self.queue.get_consumer_info(curs, self.consumer_name)
 
 
@@ -521,7 +522,7 @@ class Ticker(_Connection):
             except Exception as exc:
                 # Something bad happened, re-check the connection
                 self._logger.warning("%s: %s", type(exc).__name__, exc)
-                curs = None
+                curs = self._connection = None
             time.sleep(self.check_period)
 
     def check_pgq(self, curs):
